@@ -492,6 +492,7 @@ class StorageInputs(object):
     no_virtual_trades: t.Optional[bool] = opt_field()
     initial_soe: t.Optional[float] = 0
     symmetric_reg: t.Optional[bool] = False
+    solver: t.Optional[bool] = opt_field()
 
 
 @dataclass_json
@@ -575,6 +576,8 @@ class StandaloneStorageModel(StorageModel):
     import_limit: t.Optional[t.List[float]] = opt_field()
     export_limit: t.Optional[t.List[float]] = opt_field()
     load_peak_reduction: t.Optional[LoadPeakReduction] = opt_field()
+    project_term: t.Optional[int] = opt_field()
+    project_term_units: t.Optional[str] = opt_field()
 
 
 @string_enum
